==> reference3-1.0-sources.jar: one/xingyi/reference3/telephone/client/view/TelephoneNumberView.java <==
package one.xingyi.reference3.telephone.client.view;
//Made by one.xingyi.core.filemaker.ClientViewInterfaceFileMaker
//Defn one.xingyi.reference3.telephone.ITelephoneNumberViewDefn
import one.xingyi.core.sdk.IXingYiView;
import one.xingyi.core.annotations.XingYiGenerated;
import java.util.function.Function;
import one.xingyi.core.http.ServiceRequest;
import one.xingyi.core.http.ServiceResponse;
import one.xingyi.core.utils.IdAndValue;
import java.util.Optional;
import one.xingyi.core.optics.Lens;
import java.util.concurrent.CompletableFuture;
import one.xingyi.core.httpClient.HttpServiceCompletableFuture;
import one.xingyi.core.httpClient.client.view.UrlPattern;
import java.lang.String;
public interface TelephoneNumberView  extends IXingYiView<one.xingyi.reference3.telephone.client.entitydefn.ITelephoneNumberClientEntity>{
    //ViewFieldDom(typeDom=PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=String)), name=number, readOnly=false, lensName=lens for views not done yet, lensPath=lens path for views not done yet, javascript=function lens for views not done yet(){return lens('number');};, templated=false, deprecated=false)
    //EntityOptional[FieldDom(typeDom=PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=String)), name=number, readOnly=false, lensName=lens_TelephoneNumber_number, lensPath=number/String, javascript=function lens_TelephoneNumber_number(){return lens('number');};, templated=false, deprecated=false)]
    default public Lens<TelephoneNumberView,java.lang.String> numberLens(){ return xingYi().stringLens(one.xingyi.reference3.telephone.client.viewcompanion.TelephoneNumberViewCompanion.companion, "lens_TelephoneNumber_number");}
    default public java.lang.String number(){ return numberLens().get(this);};
    default public TelephoneNumberView withnumber(java.lang.String number){ return numberLens().set(this,number);}
}

==> reference3-1.1-sources.jar: one/xingyi/reference3/telephone/client/view/TelephoneNumberView.java <==
package one.xingyi.reference3.telephone.client.view;
//Made by one.xingyi.core.filemaker.ClientViewInterfaceFileMaker
//Defn one.xingyi.reference3.telephone.ITelephoneNumberViewDefn
import one.xingyi.core.sdk.IXingYiView;
import one.xingyi.core.annotations.XingYiGenerated;
import java.util.function.Function;
import one.xingyi.core.http.ServiceRequest;
import one.xingyi.core.http.ServiceResponse;
import one.xingyi.core.utils.IdAndValue;
import java.util.Optional;
import one.xingyi.core.optics.Lens;
import java.util.concurrent.CompletableFuture;
import one.xingyi.core.httpClient.HttpServiceCompletableFuture;
import one.xingyi.core.httpClient.client.view.UrlPattern;
import java.lang.String;
public interface TelephoneNumberView  extends IXingYiView<one.xingyi.reference3.telephone.client.entitydefn.ITelephoneNumberClientEntity>{
    //ViewFieldDom(typeDom=StringPrimitiveType(), name=number, readOnly=false, lensName=lens for views not done yet, lensPath=lens path for views not done yet, javascript=function lens for views not done yet(){return lens('number');};, templated=false, deprecated=false)
    //EntityOptional[FieldDom(typeDom=StringPrimitiveType(), name=number, readOnly=false, lensName=lens_TelephoneNumber_number, lensPath=number/String, javascript=function lens_TelephoneNumber_number(){return lens('number');};, templated=false, deprecated=false)]
    default public Lens<TelephoneNumberView,java.lang.String> numberLens(){ return xingYi().stringLens(one.xingyi.reference3.telephone.client.viewcompanion.TelephoneNumberViewCompanion.companion, "lens_TelephoneNumber_number");}
    default public java.lang.String number(){ return numberLens().get(this);};
    default public TelephoneNumberView withnumber(java.lang.String number){ return numberLens().set(this,number);}
}
